# This is a test package for OpenI PyPi

test package for OpenI 启智AI协作平台.

# 使用说明

## 安装

```bash
pip install openi-beta
```

## 令牌生成

注册启智账户，在**个人设置-应用**中生成令牌，保存口令(只会显示一次)

![alt](https://openi.pcl.ac.cn/OpenIOSSG/openi-pypi/raw/commit/8d5991eede95316b6a688135ecad790ba2ae165b/media/1.png)

![alt](https://openi.pcl.ac.cn/OpenIOSSG/openi-pypi/raw/commit/8d5991eede95316b6a688135ecad790ba2ae165b/media/2.png)

![alt](https://openi.pcl.ac.cn/OpenIOSSG/openi-pypi/raw/commit/8d5991eede95316b6a688135ecad790ba2ae165b/media/3.png)

## openi.dataset 上传数据集函数

安装完成可仿照下列示，运行即可上传数据集

```python
from openi.dataset import upload_file

upload_file(
    file = "", # 必填，文件路径(包含文件名)
    username = "", # 必填，数据集所属项目用户名
    repository = "", # 必填，数据集所属项目名
    token = "", #必填，用户启智上获取的令牌token，并对该项目数据集有权限
    
    cluster = "", # 选填，可填入GPU或NPU，不填写后台默认为NPU
    app_url = "" #选填, 默认为平台地址，开发测试用
    )
```
![alt](https://openi.pcl.ac.cn/OpenIOSSG/openi-pypi/raw/commit/8d5991eede95316b6a688135ecad790ba2ae165b/media/4.png)

## openi.modelarts NPU环境下载与上传数据

- 对应手写数字识别NPU版本_MindsporeExample [openi.py](https://openi.pcl.ac.cn/OpenIOSSG/MNIST_Example/src/branch/master/openi.py) 中的函数，可直接调用
- 本地或者非NPU环境调用将会提示无法调用
```python
from openi.modelarts import (
    openi_dataset_to_Env,
    openi_multidataset_to_env,
    pretrain_to_env,
    env_to_openi,
    obs_copy_file,
    obs_copy_folder,
    c2net_multidataset_to_env,
    EnvToOpenIEpochEnd
)
openi_dataset_to_Env("/output","/output")
```
![alt](https://openi.pcl.ac.cn/OpenIOSSG/openi-pypi/raw/commit/8d5991eede95316b6a688135ecad790ba2ae165b/media/5.png)